/*
 * softspi.h
 * by Stephan Baerwolf (stephan@matrixstorm.com), Ilmenau 2013
 * 
 * This file headers the software SPI library.
 */

#ifndef __SOFTSPI_H_229db984fe7b4d419c4c43c9ad0e2028
#	define __SOFTSPI_H_229db984fe7b4d419c4c43c9ad0e2028 1

#include "keyboard.h"
#include <stdlib.h>
#include <stdint.h>

#define SOFTSPI_CLK	KEYBOARD_LED_NUMLOCK
#define SOFTSPI_MOSI	KEYBOARD_LED_CAPSLOCK
#define SOFTSPI_SS	KEYBOARD_LED_SCROLLLOCK

#define SOFTSPI_MISO	KEYBOARD_USERDEFINEABLE

#define SOFTSPI_OUTS	(SOFTSPI_CLK | SOFTSPI_MOSI | SOFTSPI_SS)

#ifndef __SOFTSPI_C_229db984fe7b4d419c4c43c9ad0e2028
#	define SOFTSPIPUBLIC
#else
#	define SOFTSPIPUBLIC extern
#endif


/*
 * Initialisation- and finalizationfunctions of the Software SPI
 * Returns value "0" (or positive) if successful
 * otherwise it means FAIL (and no changes done)
 */
SOFTSPIPUBLIC int softspi_initialize(void);
SOFTSPIPUBLIC int softspi_finalize(void);
SOFTSPIPUBLIC int softspi_isinitialized(void);

/*
 * Changes the time delay of a quarter clockperiod.
 * Numbers are in [us].
 */
SOFTSPIPUBLIC uint32_t softspi_getclock(void);
SOFTSPIPUBLIC int softspi_setclock(uint32_t clockdelay);

/*
 * Accesses the complement-mask
 * If your external ciruit contains some complement,
 * here you can set the corresponding flag to get the
 * signal complemented by software in order to save you
 * extra hardware (not-gate).
 */
SOFTSPIPUBLIC uint8_t softspi_getcomplementmask(void);
SOFTSPIPUBLIC int softspi_setcomplementmask(uint8_t complement);


/*
 * enables/disables chips
 */
SOFTSPIPUBLIC void softspi_enable(void);
SOFTSPIPUBLIC void softspi_disable(void);

/*
 * Transmit "tx" over SPI.
 * Return result is "rx" during this period
 * WARNING: will block!
 */
SOFTSPIPUBLIC uint8_t softspi_kick(uint8_t tx);

#endif
